Welcome to oslo.db documentation!
=================================

The Oslo database handling library. Provides database connectivity
to the different backends and helper utils.

Contents:
---------

.. toctree::
   :maxdepth: 2

   readme
   installation
   usage
   contributing

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
